================================================
Making a scatter plot for a population of events
================================================
With PESummary you can scatter plot displaying the distributions of different
parameters estimated from the gravitational waves reeleased by the LIGO
Collaboration.
Here we show an example for the redshift vs total mass
distribution for all the GWTC-1 data. This is done including errorbars on the
plot. Below the image example and the script used to produce it.



.. image:: ./examples/event_scatter_plot_total_mass_and_redshift.png

.. literalinclude:: ../../../examples/gw/GWTC-1_population_scatterplot.sh
    :language: bash
    :lines: 1-29
    :linenos:

